==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/MassIndexIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { MassIndexIndicatorDescription } from "./MassIndexIndicatorDescription";
/**
 * @hidden
 */
export let MassIndexIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class MassIndexIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (MassIndexIndicatorDescriptionMetadata.a == null) {
                MassIndexIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                MassIndexIndicatorDescriptionMetadata.c(MassIndexIndicatorDescriptionMetadata.a);
            }
            if (a.k(MassIndexIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ab(MassIndexIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
        }
        static d(a) {
            MassIndexIndicatorDescriptionMetadata.b(a);
            a.ad("MassIndexIndicator", () => new MassIndexIndicatorDescription());
            a.ac("MassIndexIndicator", MassIndexIndicatorDescriptionMetadata.a);
        }
    }
    MassIndexIndicatorDescriptionMetadata.$t = markType(MassIndexIndicatorDescriptionMetadata, 'MassIndexIndicatorDescriptionMetadata');
    MassIndexIndicatorDescriptionMetadata.a = null;
    return MassIndexIndicatorDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/MassIndexIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { MassIndexIndicatorDescription } from "./MassIndexIndicatorDescription";
/**
 * @hidden
 */
export let MassIndexIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class MassIndexIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (MassIndexIndicatorDescriptionMetadata.a == null) {
                MassIndexIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                MassIndexIndicatorDescriptionMetadata.c(MassIndexIndicatorDescriptionMetadata.a);
            }
            if (a.k(MassIndexIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ac(MassIndexIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
        }
        static d(a) {
            MassIndexIndicatorDescriptionMetadata.b(a);
            a.ae("MassIndexIndicator", () => new MassIndexIndicatorDescription());
            a.ad("MassIndexIndicator", MassIndexIndicatorDescriptionMetadata.a);
        }
    }
    MassIndexIndicatorDescriptionMetadata.$t = markType(MassIndexIndicatorDescriptionMetadata, 'MassIndexIndicatorDescriptionMetadata');
    MassIndexIndicatorDescriptionMetadata.a = null;
    return MassIndexIndicatorDescriptionMetadata;
})();
